summaryrefslogtreecommitdiff
path: root/cffi/recompiler.py
diff options
context:
space:
mode:
authorSergey Vorfolomeev <sergey.vorfolomeev@vmssoftware.com>2020-10-06 16:55:06 +0500
committerSergey Vorfolomeev <sergey.vorfolomeev@vmssoftware.com>2020-10-06 16:55:06 +0500
commite676f683c867caa6118a7706266b930a62559297 (patch)
tree0a541b023913e57fa9a32e140e97bc79616e6485 /cffi/recompiler.py
parentef64e896958e20f577003341fab4fbd14f4cfb18 (diff)
downloadcffi-e676f683c867caa6118a7706266b930a62559297.tar.gz
OpenVMS fix
Diffstat (limited to 'cffi/recompiler.py')
-rw-r--r--cffi/recompiler.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/cffi/recompiler.py b/cffi/recompiler.py
index 1aeae5b..457d6f9 100644
--- a/cffi/recompiler.py
+++ b/cffi/recompiler.py
@@ -422,10 +422,10 @@ class Recompiler:
prnt(' return NULL;')
prnt('#endif')
prnt('}')
# on Windows, distutils insists on putting init_cffi_xyz in
# 'export_symbols', so instead of fighting it, just give up and
# give it one
- prnt('# ifdef _MSC_VER')
+ prnt('# if defined(_MSC_VER) || defined(__VMS)')
prnt(' PyMODINIT_FUNC')
prnt('# if PY_MAJOR_VERSION >= 3')
prnt(' PyInit_%s(void) { return NULL; }' % (base_module_name,))
@@ -1501,6 +1501,8 @@ def _patch_for_target(patchlist, target):
target += '.dll'
elif sys.platform == 'darwin':
target += '.dylib'
+ elif sys.platform == 'OpenVMS':
+ target += '.exe'
else:
target += '.so'
_patch_meth(patchlist, build_ext, 'get_ext_filename',
@@ -422,10 +422,10 @@ class Recompiler:
prnt('#endif')
prnt('}')
- # on Windows, distutils insists on putting init_cffi_xyz in
+ # on Windows and OpenVMS, distutils insists on putting init_cffi_xyz in
# 'export_symbols', so instead of fighting it, just give up and
# give it one